@@ -1,17 +1,19 @@
-#!/usr/bin/ruby
+#!/usr/bin/env ruby
 require 'mkmf'
 
-Config::CONFIG['CC']  = 'g++'
-Config::CONFIG['CPP'] = 'g++'
+ConfigClass = defined?(RbConfig) ? RbConfig : Config
 
-$CFLAGS  = '-fPIC'
+ConfigClass::CONFIG['CC']  = 'g++'
+ConfigClass::CONFIG['CPP'] = 'g++'
+
+$CFLAGS  = "-fPIC -I#{ENV['LOCALBASE']}/include"
 
 def apt_install_hint pkg
   "sudo apt-get install #{pkg}"
 end
 
 def library_installed? name, hint
-  if have_library(name)
+  if find_library(name, 'main', *%w(/usr/lib #{ENV['LOCALBASE']}/lib))
     true
   else
     $stderr.puts <<-ERROR
@@ -55,6 +57,5 @@ exit 1 unless library_installed? 'pcrecpp', apt_install_hint('libpcre3-dev')
 exit 1 unless library_installed? 'e2fs-uuid',    apt_install_hint('uuid-dev')
 exit 1 unless library_installed? 'dbic++',  apt_install_hint('dbic++-dev')
 
-assert_dbicpp_version '0.5.4'
-
+assert_dbicpp_version '0.6.0'
 create_makefile 'swift'
