@@ -1,7 +1,9 @@
 #include "query.h"
+#include <math.h>
 
-ID fstrftime, fto_s, fusec;
-VALUE dtformat, tzformat, utf8;
+ID fstrftime;
+VALUE dtformat, utf8;
+VALUE cDateTime;
 
 VALUE query_execute(Query *query) {
   try {
@@ -11,10 +13,24 @@ VALUE query_execute(Query *query) {
         : query->handle->conn()->execute(query->sql, query->bind)
     );
   }
-  catch (dbi::Error &e) {
-    snprintf(query->error, 8192, "%s", e.what());
-    return Qfalse;
+  catch (dbi::ConnectionError &e) {
+    query->error_klass = eSwiftConnectionError;
+    snprintf(query->error_message, 8192, "%s", e.what());
   }
+  catch (dbi::Error &e) {
+    query->error_klass = eSwiftRuntimeError;
+    snprintf(query->error_message, 8192, "%s", e.what());
+  }
+  catch (std::bad_alloc &e) {
+    query->error_klass = rb_eNoMemError;
+    snprintf(query->error_message, 8192, "%s", e.what());
+  }
+  catch (std::exception &e) {
+    query->error_klass = rb_eRuntimeError;
+    snprintf(query->error_message, 8192, "%s", e.what());
+  }
+
+  return Qfalse;
 }
 
 VALUE query_execute_statement(Query *query) {
@@ -25,10 +41,24 @@ VALUE query_execute_statement(Query *query) {
         : query->statement->execute(query->bind)
     );
   }
-  catch (dbi::Error &e) {
-    snprintf(query->error, 8192, "%s", e.what());
-    return Qfalse;
+  catch (dbi::ConnectionError &e) {
+    query->error_klass = eSwiftConnectionError;
+    snprintf(query->error_message, 8192, "%s", e.what());
   }
+  catch (dbi::Error &e) {
+    query->error_klass = eSwiftRuntimeError;
+    snprintf(query->error_message, 8192, "%s", e.what());
+  }
+  catch (std::bad_alloc &e) {
+    query->error_klass = rb_eNoMemError;
+    snprintf(query->error_message, 8192, "%s", e.what());
+  }
+  catch (std::exception &e) {
+    query->error_klass = rb_eRuntimeError;
+    snprintf(query->error_message, 8192, "%s", e.what());
+  }
+
+  return Qfalse;
 }
 
 void query_bind_values(Query *query, VALUE bind_values) {
@@ -48,13 +78,8 @@ void query_bind_values(Query *query, VALUE bind_values) {
       bind_value = rb_funcall(bind_value, rb_intern("read"), 0);
       query->bind.push_back(dbi::PARAM_BINARY((unsigned char*)RSTRING_PTR(bind_value), RSTRING_LEN(bind_value)));
     }
-    // TODO convert timestamps to server timezone if @timezone is set in adapter.
-    else if (rb_obj_is_kind_of(bind_value, rb_cTime)) {
+    else if (rb_obj_is_kind_of(bind_value, rb_cTime) || rb_obj_is_kind_of(bind_value, cDateTime)) {
       std::string timestamp = RSTRING_PTR(rb_funcall(bind_value, fstrftime, 1, dtformat));
-
-      timestamp += RSTRING_PTR(rb_funcall(rb_funcall(bind_value, fusec, 0), fto_s, 0));
-      timestamp += RSTRING_PTR(rb_funcall(bind_value, fstrftime, 1, tzformat));
-
       query->bind.push_back(dbi::PARAM(timestamp));
     }
     else {
@@ -67,14 +92,13 @@ void query_bind_values(Query *query, VALUE bind_values) {
 }
 
 void init_swift_query() {
-  fstrftime = rb_intern("strftime");
-  fto_s     = rb_intern("to_s");
-  fusec     = rb_intern("usec");
-  dtformat  = rb_str_new2("%F %T.");
-  tzformat  = rb_str_new2("%z");
+  rb_require("date");
+
   utf8      = rb_str_new2("UTF-8");
+  fstrftime = rb_intern("strftime");
+  dtformat  = rb_str_new2("%F %T.%N %z");
+  cDateTime = CONST_GET(rb_mKernel, "DateTime");
 
   rb_global_variable(&utf8);
-  rb_global_variable(&tzformat);
   rb_global_variable(&dtformat);
 }
