@@ -22,6 +22,6 @@ dbi::AbstractResult* result_handle(VALUE);
 
 VALUE result_each(VALUE);
 
-VALUE typecast_field(int, const char*, uint64_t, const char*);
+VALUE typecast_field(int, const char*, uint64_t);
 
 #endif
