@@ -43,7 +43,7 @@ dbi::AbstractStatement* statement_handle(VALUE self) {
   return handle->statement;
 }
 
-// TODO: Change bind_values to an array in the interface? Avoid array -> splat -> array.
+// array -> splat -> array is an overhead, but it reads nicer.
 static VALUE statement_execute(int argc, VALUE *argv, VALUE self) {
   VALUE bind_values, block;
   rb_scan_args(argc, argv, "0*&", &bind_values, &block);
@@ -56,7 +56,7 @@ static VALUE statement_execute(int argc, VALUE *argv, VALUE self) {
     if (dbi::_trace)                 dbi::logMessage(dbi::_trace_fd, dbi::formatParams(statement->command(), query.bind));
 
     if (rb_thread_blocking_region(((VALUE (*)(void*))query_execute_statement), &query, RUBY_UBF_IO, 0) == Qfalse)
-      rb_raise(eSwiftRuntimeError, "%s", query.error);
+      rb_raise(query.error_klass, "%s", query.error_message);
   }
   CATCH_DBI_EXCEPTIONS();
 
@@ -98,6 +98,10 @@ VALUE statement_initialize(VALUE self, VALUE adapter, VALUE sql) {
   return Qnil;
 }
 
+VALUE statement_command(VALUE self) {
+  return rb_iv_get(self, "@sql");
+}
+
 void init_swift_statement() {
   VALUE mSwift = rb_define_module("Swift");
 
@@ -105,5 +109,8 @@ void init_swift_statement() {
   rb_define_method(cSwiftStatement, "execute",     RUBY_METHOD_FUNC(statement_execute),   -1);
   rb_define_method(cSwiftStatement, "initialize",  RUBY_METHOD_FUNC(statement_initialize), 2);
   rb_define_method(cSwiftStatement, "insert_id",   RUBY_METHOD_FUNC(statement_insert_id),  0);
+  rb_define_method(cSwiftStatement, "command",     RUBY_METHOD_FUNC(statement_command),    0);
+
+  rb_define_alias(cSwiftStatement, "to_s", "command");
   rb_define_alloc_func(cSwiftStatement, statement_alloc);
 }
