@@ -12,6 +12,7 @@
 #define CONST_GET(scope, constant) rb_funcall(scope, rb_intern("const_get"), 1, rb_str_new2(constant))
 #define TO_S(v)                    rb_funcall(v, rb_intern("to_s"), 0)
 #define CSTRING(v)                 RSTRING_PTR(TO_S(v))
+#define RUBY_STATIC_FUNC(func)     ((int (*)(ANYARGS))func)
 
 extern VALUE eSwiftError;
 extern VALUE eSwiftArgumentError;
@@ -27,11 +28,14 @@ extern VALUE eSwiftConnectionError;
   } \
   catch (std::bad_alloc &error) { \
     rb_raise(rb_eNoMemError, "%s", error.what()); \
+  } \
+  catch (std::exception &error) { \
+    rb_raise(rb_eRuntimeError, "%s", error.what()); \
   }
 
 
 // works without a controlling tty, getlogin() will fail when process is daemonized.
-inline VALUE CURRENT_USER() {
+inline VALUE current_user() {
   struct passwd *ptr = getpwuid(getuid());
   return ptr ? rb_str_new2(ptr->pw_name) : rb_str_new2("root");
 }
@@ -41,9 +45,8 @@ inline VALUE CURRENT_USER() {
 #include "query.h"
 #include "result.h"
 #include "statement.h"
-#include "request.h"
-#include "pool.h"
 #include "attribute.h"
+#include "datetime.h"
 
 #undef SIZET2NUM
 #ifdef HAVE_LONG_LONG
