@@ -1,6 +1,8 @@
+require 'swift/adapter/sql'
+
 module Swift
   module DB
-    class Mysql < Adapter
+    class Mysql < Adapter::Sql
       def initialize options = {}
         super options.update(driver: 'mysql')
       end
@@ -18,9 +20,13 @@ module Swift
           else super
         end
       end
+
+      def tables
+        execute("show tables").map(&:values).flatten
+      end
     end # Mysql
 
-    class Sqlite3 < Adapter
+    class Sqlite3 < Adapter::Sql
       def initialize options = {}
         super options.update(driver: 'sqlite3')
       end
@@ -45,16 +51,21 @@ module Swift
           when Type::Integer    then attribute.serial ? 'integer primary key' : 'integer'
           when Type::Float      then 'float'
           when Type::BigDecimal then 'numeric'
-          when Type::Time       then 'timestamp'
+          when Type::Time       then 'timestamp' # deprecated
+          when Type::DateTime   then 'timestamp'
           when Type::Date       then 'date'
           when Type::Boolean    then 'boolean'
           when Type::IO         then 'blob'
           else 'text'
         end
       end
+
+      def tables
+        execute('select name from sqlite_master where type = ?', 'table').map(&:values).flatten
+      end
     end # Sqlite3
 
-    class Postgres < Adapter
+    class Postgres < Adapter::Sql
       def initialize options = {}
         super options.update(driver: 'postgresql')
       end
@@ -69,6 +80,10 @@ module Swift
           else super
         end
       end
+
+      def tables
+        execute('select tablename from pg_tables where schemaname = current_schema').map(&:values).flatten
+      end
     end # Postgres
   end # DB
 end # Swift
