@@ -1,8 +1,11 @@
 $:.unshift(File.join(File.dirname(__FILE__), '..', 'lib'))
+$:.unshift(File.join(File.dirname(__FILE__), '..', 'test'))
 
 require 'minitest/spec'
 require 'minitest/unit'
+require 'minitest_teardown_hack'
 require 'swift'
+require 'swift/migrations'
 require 'etc'
 
 class MiniTest::Spec
@@ -21,6 +24,9 @@ class MiniTest::Spec
         before do
           Swift.setup :default, adapter, connection_defaults.merge(adapter_defaults.fetch(adapter, {}))
         end
+        after do
+          Swift.db.close
+        end
         block.call(adapter)
       end
     end
