@@ -26,6 +26,12 @@ describe 'Adapter' do
         Swift.trace false
       end
 
+      it 'records closed state' do
+        assert !Swift.db.closed?
+        Swift.db.close
+        assert Swift.db.closed?
+      end
+
       describe 'execute' do
         it 'executes without bind values' do
           assert @db.execute %q{select count(*) from users}
@@ -47,6 +53,12 @@ describe 'Adapter' do
           assert @db.prepare(%q{insert into users (name) values ('Apple Arthurton')}).execute
         end
 
+        it 'returns the command' do
+          sql = 'select * from users where id = ?'
+          assert_equal sql, @db.prepare(sql).command
+          assert_equal sql, @db.prepare(sql).to_s
+        end
+
         it 'executes with bind values' do
           assert @db.prepare(%q{insert into users (name) values (?)}).execute('Apple Arthurton')
         end
@@ -108,10 +120,18 @@ describe 'Adapter' do
         end
       end
 
+      describe 'schema information' do
+        it 'should list tables' do
+          assert_equal %w(users), @db.tables
+        end
+
+        it 'should list fields in a table with types' do
+          expect = {id: 'integer', name: 'text', email: 'text', created_at: 'timestamp'}
+          assert_equal expect, @db.fields('users')
+        end
+      end
+
 
-      #--
-      # TODO: Not sure how I feel about the block in write; feels like it's just there to get around the fields in the
-      # argument list. How about write('users', %w{name, email, balance}, data)?
       describe 'bulk writes!' do
         it 'writes from an IO object' do
           data = StringIO.new "Sally Arthurton\tsally@local\nJonas Arthurton\tjonas@local\n"
@@ -124,7 +144,7 @@ describe 'Adapter' do
         end
 
         it 'writes with no columns specified' do
-          ts   = DateTime.parse('2010-01-01 00:00:00').to_time
+          ts   = DateTime.parse('2010-01-01 00:00:00')
           data = "1\tSally Arthurton\tsally@local\t#{ts}\n"
           row  = {id: 1, name: 'Sally Arthurton', email: 'sally@local', created_at: ts}
 
